# score-scraper
Scrape game informations and scores from:
* flashscore
* kicker

Support planned for:
* sofascore

**Caution: No safety checks implemented.**

## How to install
```
pip install score-scraper
```

## License
MIT


